@@ -52,11 +52,17 @@ class RedSSH(object):
     :type set_flags: ``dict``
     :param method_preferences: Not supported in ssh2-python 0.18.0
     :type method_preferences: ``dict``
+    :param callbacks: Not supported yet
+    :type callbacks: ``dict``
+    :param auto_terminate_tunnels: Automatically terminate tunnels when errors are detected
+    :type auto_terminate_tunnels: ``bool``
+    :param tcp_nodelay: Set `TCP_NODELAY` for the underlying :func:`socket.socket`, by default this is off via `False`.
+    :type tcp_nodelay: ``bool``
     '''
     def __init__(self,encoding='utf8',terminal='vt100',known_hosts=None
         ,ssh_host_key_verification=enums.SSHHostKeyVerify.warn,
         ssh_keepalive_interval=0.0,set_flags={},method_preferences={},
-        callbacks={},auto_terminate_tunnels=False):
+        callbacks={},auto_terminate_tunnels=False,tcp_nodelay=False):
         self.debug = False
         self._auto_select_timeout_enabled = False
         self._select_timeout = 0.005
@@ -78,6 +84,7 @@ class RedSSH(object):
         self.method_preferences = method_preferences
         self.callbacks = callbacks
         self.auto_terminate_tunnels = auto_terminate_tunnels
+        self.tcp_nodelay = tcp_nodelay
         self._ssh_keepalive_thread = None
         self._ssh_keepalive_event = None
         if known_hosts==None:
@@ -335,7 +342,7 @@ class RedSSH(object):
         :param look_for_keys: Enable offering keys in ``~/.ssh`` automatically. NOT IMPLEMENTED!
         :type look_for_keys: ``bool``
         :param sock: A pre-connected socket to the remote server. Useful if you have strange network requirements.
-        :type sock: ``socket``
+        :type sock: :func:`socket.socket`
         :param timeout: Timeout for the socket connection to the remote server.
         :type timeout: ``float``
         '''
@@ -346,6 +353,7 @@ class RedSSH(object):
                 __initial = time.time()
                 self.sock = socket.create_connection((hostname,port),timeout)
                 self.sock.setsockopt(socket.SOL_SOCKET,socket.SO_KEEPALIVE,1)
+                self.sock.setsockopt(socket.IPPROTO_TCP,socket.TCP_NODELAY,self.tcp_nodelay)
                 new_select_timeout = float(time.time()-__initial)*0.95
                 if new_select_timeout>self._select_timeout and self._auto_select_timeout_enabled==True:
                     self._select_timeout = new_select_timeout
@@ -511,32 +519,31 @@ class RedSSH(object):
         :type error_level: :class:`redssh.enums.TunnelErrorLevel`
         :return: ``int`` The local port that has been bound.
         '''
-        assert isinstance(remote_host,type(''))
-        assert isinstance(remote_port,type(0))
-        option_string = str(bind_addr)+':'+str(local_port)+':'+remote_host+':'+str(remote_port)
-        if not option_string in self.tunnels[enums.TunnelType.local.value]:
-            wait_for_chan = threading.Event()
-            thread_terminate = threading.Event()
+        if isinstance(remote_host,type('')) and isinstance(remote_port,type(0)):
+            option_string = str(bind_addr)+':'+str(local_port)+':'+remote_host+':'+str(remote_port)
+            if not option_string in self.tunnels[enums.TunnelType.local.value]:
+                wait_for_chan = threading.Event()
+                thread_terminate = threading.Event()
 
-            class SubHander(tunneling.LocalPortServerHandler):
-                ssh_session = self
-                chain_host = remote_host
-                chain_port = remote_port
-                terminate = thread_terminate
-                wchan = wait_for_chan
+                class SubHander(tunneling.LocalPortServerHandler):
+                    ssh_session = self
+                    chain_host = remote_host
+                    chain_port = remote_port
+                    terminate = thread_terminate
+                    wchan = wait_for_chan
 
-            tun_server = tunneling.LocalPortServer((bind_addr,local_port),SubHander,self,thread_terminate,remote_host,remote_port,wait_for_chan,error_level)
-            tun_thread = threading.Thread(target=tun_server.serve_forever)
-            tun_thread.daemon = True
-            tun_thread.name = enums.TunnelType.local.value+':'+option_string
-            tun_thread.start()
-            wait_for_chan.wait()
-            if local_port==0:
-                local_port = tun_server.socket.getsockname()[1]
-                option_string = str(bind_addr)+':'+str(local_port)+':'+remote_host+':'+str(remote_port)
+                tun_server = tunneling.LocalPortServer((bind_addr,local_port),SubHander,self,thread_terminate,remote_host,remote_port,wait_for_chan,error_level)
+                tun_thread = threading.Thread(target=tun_server.serve_forever)
+                tun_thread.daemon = True
                 tun_thread.name = enums.TunnelType.local.value+':'+option_string
-            self.tunnels[enums.TunnelType.local.value][option_string] = (tun_thread,thread_terminate,tun_server,local_port)
-        return(local_port)
+                tun_thread.start()
+                wait_for_chan.wait()
+                if local_port==0:
+                    local_port = tun_server.socket.getsockname()[1]
+                    option_string = str(bind_addr)+':'+str(local_port)+':'+remote_host+':'+str(remote_port)
+                    tun_thread.name = enums.TunnelType.local.value+':'+option_string
+                self.tunnels[enums.TunnelType.local.value][option_string] = (tun_thread,thread_terminate,tun_server,local_port)
+            return(local_port)
 
     def remote_tunnel(self,local_port,remote_host,remote_port,bind_addr='127.0.0.1',error_level=enums.TunnelErrorLevel.warn):
         '''
